@@ -113,6 +113,14 @@ class FormBlock(blocks.StructBlock):
         label = "Form"
 
 
+class PersonBlock(blocks.StructBlock):
+    person = SnippetChooserBlock('cms.Person', required=True)
+
+    class Meta:
+        template = '%s/common/person.html' % constants.BLOCK_TEMPLATES_PATH
+        label = "Person"
+
+
 class EntryBlock(Mocker, blocks.StructBlock):
     bg_desktop = blocks.StreamBlock(
         [
